HismaRouterDelegate<S, E> class

Inheritance
Mixed-in types

Constructors

HismaRouterDelegate({required NavigationMachine<S, E, dynamic> machine, required Map<S, Presentation> mapping})

Properties

currentConfiguration → S?
Called by the Router when it detects a route information may have changed as a result of rebuild.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
machine NavigationMachine<S, E, dynamic>
Machine that this router delegate represents.
final
mapping Map<S, Presentation>
Mapping machine states to a presentation.
final
Required to find NavigatorState corresponding to this RouterDelegate.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stack → StateStack
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
build(BuildContext context) Widget
Called by the Router to obtain the widget tree that represents the current state.
override
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
popRoute() Future<bool>
Handles the back button request from the operating system. It will try to pop the current route from the navigator first and in that case the onPopPage will handle the corresponding state machine event firing. If it does not succeed it will try to fire the event defined for the current state's presentation to move in the state machine.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setInitialRoutePath(S configuration) Future<void>
Called by the Router at startup with the structure that the RouteInformationParser obtained from parsing the initial route.
inherited
setNewRoutePath(S configuration) Future<void>
Called by the Router when the Router.routeInformationProvider reports that a new route has been pushed to the application by the operating system.
override
setRestoredRoutePath(S configuration) Future<void>
Called by the Router during state restoration.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited