PagelessCreator<E, R> class

Inheritance

Constructors

PagelessCreator({required Presenter<R> presenter, required bool rootNavigator, E? event})

Properties

event ↔ E?
Event to be fired when presentation is dismissed e.g. dialog popped.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
presenter Presenter<R>
getter/setter pair
rootNavigator bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close([R? result]) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(BuildContext? context, dynamic arg) Future<R?>
override
setClosed() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited