HismaRouterGenerator<S, E> class
Constructors
-
HismaRouterGenerator({required NavigationMachine<
S, E, dynamic> machine, required Map<S, Presentation> mapping})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
machine
→ NavigationMachine<
S, E, dynamic> -
final
-
mapping
→ Map<
S, Presentation> -
final
-
routeInformationParser
→ RouteInformationParser<
S> -
no setter
-
routerDelegate
→ HismaRouterDelegate<
S, E> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited